/*
Copyright [2020] [https://www.xiaonuo.vip]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：

1.请不要删除和修改根目录下的LICENSE文件。
2.请不要删除和修改Snowy源码头部的版权声明。
3.请保留源码和相关描述文件的项目出处，作者声明等。
4.分发源码时候，请注明软件出处 https://gitee.com/xiaonuobase/snowy
5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/xiaonuobase/snowy
6.若您的项目无法满足以上几点，可申请商业授权，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.huimv.modular.alarmrecord.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.core.consts.CommonConstant;
import com.huimv.core.enums.CommonStatusEnum;
import com.huimv.core.exception.ServiceException;
import com.huimv.core.factory.PageFactory;
import com.huimv.core.pojo.page.PageResult;
import com.huimv.core.util.PoiUtil;
import com.huimv.modular.alarmrecord.entity.AlarmRecord;
import com.huimv.modular.alarmrecord.enums.AlarmRecordExceptionEnum;
import com.huimv.modular.alarmrecord.mapper.AlarmRecordMapper;
import com.huimv.modular.alarmrecord.param.AlarmRecordParam;
import com.huimv.modular.alarmrecord.service.AlarmRecordService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import javax.annotation.Resource;
import java.util.List;

/**
 * 报警记录service接口实现类
 *
 * @author ydd
 * @date 2021-08-20 13:27:00
 */
@Service
public class AlarmRecordServiceImpl extends ServiceImpl<AlarmRecordMapper, AlarmRecord> implements AlarmRecordService {

    @Override
    public PageResult<AlarmRecord> page(AlarmRecordParam alarmRecordParam) {
        QueryWrapper<AlarmRecord> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isNotNull(alarmRecordParam)) {

            // 根据组织id 查询
            if (ObjectUtil.isNotEmpty(alarmRecordParam.getOrgId())) {
                queryWrapper.lambda().eq(AlarmRecord::getOrgId, alarmRecordParam.getOrgId());
            }
            // 根据牧场编码 查询
            if (ObjectUtil.isNotEmpty(alarmRecordParam.getFarmCode())) {
                queryWrapper.lambda().eq(AlarmRecord::getFarmCode, alarmRecordParam.getFarmCode());
            }
            // 根据 查询
            if (ObjectUtil.isNotEmpty(alarmRecordParam.getFarmName())) {
                queryWrapper.lambda().eq(AlarmRecord::getFarmName, alarmRecordParam.getFarmName());
            }
            // 根据 查询
            if (ObjectUtil.isNotEmpty(alarmRecordParam.getEartagNo())) {
                queryWrapper.lambda().eq(AlarmRecord::getEartagNo, alarmRecordParam.getEartagNo());
            }
            // 根据采集器编码 查询
            if (ObjectUtil.isNotEmpty(alarmRecordParam.getCollectorCode())) {
                queryWrapper.lambda().eq(AlarmRecord::getCollectorCode, alarmRecordParam.getCollectorCode());
            }
            // 根据猪舍id 查询
            if (ObjectUtil.isNotEmpty(alarmRecordParam.getPenId())) {
                queryWrapper.lambda().eq(AlarmRecord::getPenId, alarmRecordParam.getPenId());
            }
            // 根据单元id 查询
            if (ObjectUtil.isNotEmpty(alarmRecordParam.getUnitId())) {
                queryWrapper.lambda().eq(AlarmRecord::getUnitId, alarmRecordParam.getUnitId());
            }
            // 根据类型 查询
            if (ObjectUtil.isNotEmpty(alarmRecordParam.getAlarmType())) {
                queryWrapper.lambda().eq(AlarmRecord::getAlarmType, alarmRecordParam.getAlarmType());
            }
            // 根据当前报警数值 查询
            if (ObjectUtil.isNotEmpty(alarmRecordParam.getNowValue())) {
                queryWrapper.lambda().eq(AlarmRecord::getNowValue, alarmRecordParam.getNowValue());
            }
            // 根据是否被处理-0.否--1.是 查询
            if (ObjectUtil.isNotEmpty(alarmRecordParam.getStatus())) {
                queryWrapper.lambda().eq(AlarmRecord::getStatus, alarmRecordParam.getStatus());
            }
            // 根据备注 查询
            if (ObjectUtil.isNotEmpty(alarmRecordParam.getRemark())) {
                queryWrapper.lambda().eq(AlarmRecord::getRemark, alarmRecordParam.getRemark());
            }
        }
        return new PageResult<>(this.page(PageFactory.defaultPage(), queryWrapper));
    }

    @Override
    public List<AlarmRecord> list(AlarmRecordParam alarmRecordParam) {
        return this.list();
    }

    @Override
    public void add(AlarmRecordParam alarmRecordParam) {
        AlarmRecord alarmRecord = new AlarmRecord();
        BeanUtil.copyProperties(alarmRecordParam, alarmRecord);
        this.save(alarmRecord);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<AlarmRecordParam> alarmRecordParamList) {
        alarmRecordParamList.forEach(alarmRecordParam -> {
            this.removeById(alarmRecordParam.getId());
        });
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(AlarmRecordParam alarmRecordParam) {
        AlarmRecord alarmRecord = this.queryAlarmRecord(alarmRecordParam);
        BeanUtil.copyProperties(alarmRecordParam, alarmRecord);
        this.updateById(alarmRecord);
    }

    @Override
    public AlarmRecord detail(AlarmRecordParam alarmRecordParam) {
        return this.queryAlarmRecord(alarmRecordParam);
    }

    /**
     * 获取报警记录
     *
     * @author ydd
     * @date 2021-08-20 13:27:00
     */
    private AlarmRecord queryAlarmRecord(AlarmRecordParam alarmRecordParam) {
        AlarmRecord alarmRecord = this.getById(alarmRecordParam.getId());
        if (ObjectUtil.isNull(alarmRecord)) {
            throw new ServiceException(AlarmRecordExceptionEnum.NOT_EXIST);
        }
        return alarmRecord;
    }

    @Override
    public void export(AlarmRecordParam alarmRecordParam) {
        List<AlarmRecord> list = this.list(alarmRecordParam);
        PoiUtil.exportExcelWithStream("SnowyAlarmRecord.xls", AlarmRecord.class, list);
    }

}
