/*
Copyright [2020] [https://www.xiaonuo.vip]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：

1.请不要删除和修改根目录下的LICENSE文件。
2.请不要删除和修改Snowy源码头部的版权声明。
3.请保留源码和相关描述文件的项目出处，作者声明等。
4.分发源码时候，请注明软件出处 https://gitee.com/xiaonuobase/snowy
5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/xiaonuobase/snowy
6.若您的项目无法满足以上几点，可申请商业授权，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.huimv.modular.alarmvalueset.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;


import com.huimv.core.exception.ServiceException;
import com.huimv.core.factory.PageFactory;
import com.huimv.core.pojo.page.PageResult;
import com.huimv.core.util.PoiUtil;
import com.huimv.modular.alarmvalueset.entity.AlarmValueSet;
import com.huimv.modular.alarmvalueset.enums.AlarmValueSetExceptionEnum;
import com.huimv.modular.alarmvalueset.mapper.AlarmValueSetMapper;
import com.huimv.modular.alarmvalueset.param.AlarmValueSetParam;
import com.huimv.modular.alarmvalueset.service.AlarmValueSetService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 报警参数设置service接口实现类
 *
 * @author ydd
 * @date 2021-08-20 13:23:30
 */
@Service
public class AlarmValueSetServiceImpl extends ServiceImpl<AlarmValueSetMapper, AlarmValueSet> implements AlarmValueSetService {

    @Override
    public PageResult page(AlarmValueSetParam alarmValueSetParam) {
        QueryWrapper<AlarmValueSet> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isNotNull(alarmValueSetParam)) {

            // 根据组织id 查询
            if (ObjectUtil.isNotEmpty(alarmValueSetParam.getOrgId())) {
                queryWrapper.lambda().eq(AlarmValueSet::getOrgId, alarmValueSetParam.getOrgId());
            }
            // 根据牧场编码 查询
            if (ObjectUtil.isNotEmpty(alarmValueSetParam.getFarmCode())) {
                queryWrapper.lambda().eq(AlarmValueSet::getFarmCode, alarmValueSetParam.getFarmCode());
            }
            // 根据牧场名称 查询
            if (ObjectUtil.isNotEmpty(alarmValueSetParam.getFarmName())) {
                queryWrapper.lambda().eq(AlarmValueSet::getFarmName, alarmValueSetParam.getFarmName());
            }
            // 根据1.耳温高2.耳温低3.环温高4.环温低5.设备掉线6.疫病报警 查询
            if (ObjectUtil.isNotEmpty(alarmValueSetParam.getAlarmType())) {
                queryWrapper.lambda().eq(AlarmValueSet::getAlarmType, alarmValueSetParam.getAlarmType());
            }
            // 根据设定值 查询
            if (ObjectUtil.isNotEmpty(alarmValueSetParam.getSetValue())) {
                queryWrapper.lambda().eq(AlarmValueSet::getSetValue, alarmValueSetParam.getSetValue());
            }
            // 根据备注 查询
            if (ObjectUtil.isNotEmpty(alarmValueSetParam.getRemark())) {
                queryWrapper.lambda().eq(AlarmValueSet::getRemark, alarmValueSetParam.getRemark());
            }
            // 根据0.在使用  1.停止使用 查询
            if (ObjectUtil.isNotEmpty(alarmValueSetParam.getCanStatus())) {
                queryWrapper.lambda().eq(AlarmValueSet::getCanStatus, alarmValueSetParam.getCanStatus());
            }
        }
        return new PageResult<>(this.page(PageFactory.defaultPage(), queryWrapper));
    }

    @Override
    public List<AlarmValueSet> list(AlarmValueSetParam alarmValueSetParam) {
        return this.list();
    }

    @Override
    public void add(AlarmValueSetParam alarmValueSetParam) {
        AlarmValueSet alarmValueSet = new AlarmValueSet();



        BeanUtil.copyProperties(alarmValueSetParam, alarmValueSet);
        this.save(alarmValueSet);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<AlarmValueSetParam> alarmValueSetParamList) {
        alarmValueSetParamList.forEach(alarmValueSetParam -> {
            this.removeById(alarmValueSetParam.getId());
        });
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(AlarmValueSetParam alarmValueSetParam) {
        AlarmValueSet alarmValueSet = this.queryAlarmValueSet(alarmValueSetParam);
        BeanUtil.copyProperties(alarmValueSetParam, alarmValueSet);
        this.updateById(alarmValueSet);
    }

    @Override
    public AlarmValueSet detail(AlarmValueSetParam alarmValueSetParam) {
        return this.queryAlarmValueSet(alarmValueSetParam);
    }

    /**
     * 获取报警参数设置
     *
     * @author ydd
     * @date 2021-08-20 13:23:30
     */
    private AlarmValueSet queryAlarmValueSet(AlarmValueSetParam alarmValueSetParam) {
        AlarmValueSet alarmValueSet = this.getById(alarmValueSetParam.getId());
        if (ObjectUtil.isNull(alarmValueSet)) {
            throw new ServiceException(AlarmValueSetExceptionEnum.NOT_EXIST);
        }
        return alarmValueSet;
    }

    @Override
    public void export(AlarmValueSetParam alarmValueSetParam) {
        List<AlarmValueSet> list = this.list(alarmValueSetParam);
        PoiUtil.exportExcelWithStream("SnowyAlarmValueSet.xls", AlarmValueSet.class, list);
    }

}
