/*
Copyright [2020] [https://www.xiaonuo.vip]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：

1.请不要删除和修改根目录下的LICENSE文件。
2.请不要删除和修改Snowy源码头部的版权声明。
3.请保留源码和相关描述文件的项目出处，作者声明等。
4.分发源码时候，请注明软件出处 https://gitee.com/xiaonuobase/snowy
5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/xiaonuobase/snowy
6.若您的项目无法满足以上几点，可申请商业授权，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.huimv.modular.basepigpen.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.core.annotion.BusinessLog;
import com.huimv.core.annotion.DataScope;
import com.huimv.core.annotion.Permission;
import com.huimv.core.context.login.LoginContextHolder;
import com.huimv.core.enums.LogAnnotionOpTypeEnum;
import com.huimv.core.pojo.response.ResponseData;
import com.huimv.core.pojo.response.SuccessResponseData;
import com.huimv.modular.basepigpen.entity.BasePigpen;
import com.huimv.modular.basepigpen.param.BasePigpenParam;
import com.huimv.modular.basepigpen.service.BasePigpenService;
import com.huimv.modular.collectorregister.param.CollectorRegisterParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import javax.annotation.Resource;
import java.util.List;

/**
 * 栋舍表控制器
 *
 * @author yinhao
 * @date 2021-08-17 14:00:42
 */
@RestController
public class BasePigpenController {

    @Resource
    private BasePigpenService basePigpenService;

    /**
     * 查询栋舍表
     *
     * @author yinhao
     * @date 2021-08-17 14:00:42
     */
    @Permission
    @GetMapping("/basePigpen/page")
    @BusinessLog(title = "设备管理_查询", opType = LogAnnotionOpTypeEnum.QUERY)
    public ResponseData page(BasePigpenParam basePigpenParam) {
        return new SuccessResponseData(basePigpenService.page(basePigpenParam));
    }

    /**
     * 添加栋舍表
     *
     * @author yinhao
     * @date 2021-08-17 14:00:42
     */
    @Permission
    @PostMapping("/basePigpen/add")
    @BusinessLog(title = "设备管理_增加", opType = LogAnnotionOpTypeEnum.ADD)
    public ResponseData add(@RequestBody @Validated(BasePigpenParam.add.class) BasePigpenParam basePigpenParam) {

        Long sysLoginUserOrgId = LoginContextHolder.me().getSysLoginUserOrgId();
        basePigpenParam.setOrgId(sysLoginUserOrgId);
        if (basePigpenParam.getType() == 2){
            Integer stage = basePigpenService.getOne(new QueryWrapper<BasePigpen>().eq("id", basePigpenParam.getParentId())).getStage();
            basePigpenParam.setStage(stage);
        }

        basePigpenService.add(basePigpenParam);
        return new SuccessResponseData();
    }

    /**
     * 删除栋舍表，可批量删除
     *
     * @author yinhao
     * @date 2021-08-17 14:00:42
     */
    @Permission
    @PostMapping("/basePigpen/delete")
    @BusinessLog(title = "设备管理_删除", opType = LogAnnotionOpTypeEnum.DELETE)
    public ResponseData delete(@RequestBody List<Integer> ids) {
        return   basePigpenService.delete(ids);
    }

    /**
     * 编辑栋舍表
     *
     * @author yinhao
     * @date 2021-08-17 14:00:42
     */
    @Permission
    @PostMapping("/basePigpen/edit")
    @BusinessLog(title = "设备管理_编辑", opType = LogAnnotionOpTypeEnum.EDIT)
    public ResponseData edit(@RequestBody @Validated(BasePigpenParam.edit.class) BasePigpenParam basePigpenParam) {
            basePigpenService.edit(basePigpenParam);
        return new SuccessResponseData();
    }

    /**
     * 查看栋舍表
     *
     * @author yinhao
     * @date 2021-08-17 14:00:42
     */
    @Permission
    @GetMapping("/basePigpen/detail")
    @BusinessLog(title = "设备管理_查看", opType = LogAnnotionOpTypeEnum.DETAIL)
    public ResponseData detail(@Validated(BasePigpenParam.detail.class) BasePigpenParam basePigpenParam) {
        return new SuccessResponseData(basePigpenService.detail(basePigpenParam));
    }

    /**
     * 栋舍表列表
     *
     * @author yinhao
     * @date 2021-08-17 14:00:42
     */
    @Permission
    @GetMapping("/basePigpen/list")
    @BusinessLog(title = "设备管理_列表", opType = LogAnnotionOpTypeEnum.QUERY)
    public ResponseData list(BasePigpenParam basePigpenParam) {
        return new SuccessResponseData(basePigpenService.list(basePigpenParam));
    }

    @GetMapping("/basePigpen/listPigpen")
    public ResponseData listPigpen() {
        return new SuccessResponseData(basePigpenService.listPigpen());
    }


    @GetMapping("/basePigpen/listUnit")
    public ResponseData listUnit(Integer id) {
        return new SuccessResponseData(basePigpenService.listUnit(id));
    }
}
