/*
Copyright [2020] [https://www.xiaonuo.vip]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：

1.请不要删除和修改根目录下的LICENSE文件。
2.请不要删除和修改Snowy源码头部的版权声明。
3.请保留源码和相关描述文件的项目出处，作者声明等。
4.分发源码时候，请注明软件出处 https://gitee.com/xiaonuobase/snowy
5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/xiaonuobase/snowy
6.若您的项目无法满足以上几点，可申请商业授权，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.huimv.modular.collectorregister.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.huimv.core.annotion.BusinessLog;
import com.huimv.core.annotion.DataScope;
import com.huimv.core.annotion.Permission;
import com.huimv.core.enums.LogAnnotionOpTypeEnum;
import com.huimv.core.pojo.response.ErrorResponseData;
import com.huimv.core.pojo.response.ResponseData;
import com.huimv.core.pojo.response.SuccessResponseData;
import com.huimv.modular.collectorregister.entity.CollectorRegister;
import com.huimv.modular.collectorregister.param.CollectorRegisterParam;
import com.huimv.modular.collectorregister.service.CollectorRegisterService;
import com.huimv.modular.eartagregister.entity.EartagRegister;
import com.huimv.modular.eartagregister.service.EartagRegisterService;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import javax.annotation.Resource;
import java.util.Arrays;
import java.util.List;

/**
 * 设备管理控制器
 *
 * @author yinhao
 * @date 2021-08-19 09:43:52
 */
@RestController
public class CollectorRegisterController {

    @Resource
    private CollectorRegisterService collectorRegisterService;

    @Resource
    private EartagRegisterService eartagRegisterService;

    /**
     * 查询设备管理
     *
     * @author yinhao
     * @date 2021-08-19 09:43:52
     */
    @Permission
    @GetMapping("/collectorRegister/page")
    public ResponseData page(CollectorRegisterParam collectorRegisterParam) {
        return new SuccessResponseData(collectorRegisterService.page(collectorRegisterParam));
    }
    /**
     * 添加设备管理
     *
     * @author yinhao
     * @date 2021-08-19 09:43:52
     */
    @Permission
    @PostMapping("/collectorRegister/add")
    public ResponseData add(@RequestBody @Validated(CollectorRegisterParam.add.class) CollectorRegisterParam collectorRegisterParam) {
            collectorRegisterService.add(collectorRegisterParam);
        return new SuccessResponseData();
    }

    /**
     * 删除设备管理，可批量删除
     *
     * @author yinhao
     * @date 2021-08-19 09:43:52
     */
    @PostMapping("/collectorRegister/delete")
    public ResponseData delete(@RequestBody @Validated(CollectorRegisterParam.delete.class) List<Integer> ids) {
        if (ids == null || ids.size() == 0){
            return ResponseData.error("请选择设备");
        }
        for (Integer id : ids) {
            CollectorRegister collectorRegisterEntity= collectorRegisterService.getById(id);
            String deviceCode = collectorRegisterEntity.getDeviceCode();

            int count = eartagRegisterService.count(Wrappers.<EartagRegister>lambdaQuery().eq(EartagRegister::getDeviceCode, deviceCode));
            if (count > 0){
                return ResponseData.error("删除失败，设备号为"+collectorRegisterEntity.getDeviceCode()+"的设备下有未清理耳标");
            }
        }

            collectorRegisterService.delete(ids);
        return new SuccessResponseData();
    }

    /**
     * 编辑设备管理
     *
     * @author yinhao
     * @date 2021-08-19 09:43:52
     */
    @PostMapping("/collectorRegister/edit")
    public ResponseData edit(@RequestBody @Validated(CollectorRegisterParam.edit.class) CollectorRegisterParam collectorRegisterParam) {
            collectorRegisterService.edit(collectorRegisterParam);
        return new SuccessResponseData();
    }

    /**
     * 查看设备管理
     *
     * @author yinhao
     * @date 2021-08-19 09:43:52
     */
    @GetMapping("/collectorRegister/detail")
    public ResponseData detail(@Validated(CollectorRegisterParam.detail.class) CollectorRegisterParam collectorRegisterParam) {
        return new SuccessResponseData(collectorRegisterService.detail(collectorRegisterParam));
    }

    @PostMapping("/collectorRegister/logout")
    public ResponseData logout(@RequestBody CollectorRegister collectorRegister) {
        Integer id = collectorRegister.getId();
        CollectorRegister byId = collectorRegisterService.getById(id);
        if ( 0 ==byId.getCanStatus() ){
            byId.setCanStatus(3);
        }else {
            byId.setCanStatus(0);
        }
        collectorRegisterService.updateById(byId);
        return new SuccessResponseData();
    }

    /**
     * 设备管理列表
     *
     * @author yinhao
     * @date 2021-08-19 09:43:52
     */
    @GetMapping("/collectorRegister/list")
    public ResponseData list(CollectorRegisterParam collectorRegisterParam) {
        return new SuccessResponseData(collectorRegisterService.list(collectorRegisterParam));
    }

    /**
     * 采集器总数
     *
     * @author yinhao
     * @date 2021-08-19 09:43:52
     */
    @GetMapping("/collectorRegister/selectPcEveryStatusCollectors")
    public ResponseData selectPcEveryStatusCollectors(Long orgId) {
        return collectorRegisterService.selectPcEveryStatusCollectors(orgId);
    }

}
