/*
Copyright [2020] [https://www.xiaonuo.vip]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：

1.请不要删除和修改根目录下的LICENSE文件。
2.请不要删除和修改Snowy源码头部的版权声明。
3.请保留源码和相关描述文件的项目出处，作者声明等。
4.分发源码时候，请注明软件出处 https://gitee.com/xiaonuobase/snowy
5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/xiaonuobase/snowy
6.若您的项目无法满足以上几点，可申请商业授权，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.huimv.modular.dailytabulatedata.param;

import com.huimv.core.pojo.base.param.BaseParam;
import lombok.Data;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.NotBlank;
import java.util.*;

/**
* 耳标每日汇总表参数类
 *
 * @author yinhao
 * @date 2021-08-17 14:34:00
*/
@Data
public class DailyTabulateDataParam extends BaseParam {

    /**
     * 
     */
    @NotNull(message = "不能为空，请检查id参数", groups = {edit.class, delete.class, detail.class})
    private Integer id;

    /**
     * 统计日期
     */
    @NotNull(message = "统计日期不能为空，请检查statisticDate参数", groups = {add.class, edit.class})
    private String statisticDate;

    /**
     * 当日母猪总存栏
     */
    @NotNull(message = "当日母猪总存栏不能为空，请检查stockTotal参数", groups = {add.class, edit.class})
    private Integer stockTotal;

    /**
     * 每日母猪新增耳标数
     */
    @NotNull(message = "每日母猪新增耳标数不能为空，请检查stockNew参数", groups = {add.class, edit.class})
    private Integer stockNew;

    /**
     * 每日离线耳标数
     */
    @NotNull(message = "每日离线耳标数不能为空，请检查offlineNo参数", groups = {add.class, edit.class})
    private Integer offlineNo;

    /**
     * 能繁母猪存栏数
     */
    @NotNull(message = "能繁母猪存栏数不能为空，请检查sowStock参数", groups = {add.class, edit.class})
    private Integer sowStock;

    /**
     * 日龄占比（250-1000）
     */
    @NotBlank(message = "日龄占比（250-1000）不能为空，请检查ratio1参数", groups = {add.class, edit.class})
    private String ratio1;

    /**
     * 日龄（1000-1700）
     */
    @NotBlank(message = "日龄（1000-1700）不能为空，请检查ratio2参数", groups = {add.class, edit.class})
    private String ratio2;

    /**
     * 日龄（1700-2400）
     */
    @NotBlank(message = "日龄（1700-2400）不能为空，请检查ratio3参数", groups = {add.class, edit.class})
    private String ratio3;

    /**
     * 日龄（>2400)
     */
    @NotBlank(message = "日龄（>2400)不能为空，请检查ratio4参数", groups = {add.class, edit.class})
    private String ratio4;

    /**
     * 配怀存栏
     */
    @NotNull(message = "配怀存栏不能为空，请检查stock1参数", groups = {add.class, edit.class})
    private Integer stock1;

    /**
     * 分娩存栏
     */
    @NotNull(message = "分娩存栏不能为空，请检查stock2参数", groups = {add.class, edit.class})
    private Integer stock2;

    /**
     * 空怀母猪
     */
    @NotNull(message = "空怀母猪不能为空，请检查stock3参数", groups = {add.class, edit.class})
    private Integer stock3;

    /**
     * 后备存栏
     */
    @NotNull(message = "后备存栏不能为空，请检查stock4参数", groups = {add.class, edit.class})
    private Integer stock4;

    /**
     * 公猪存栏
     */
    @NotNull(message = "公猪存栏不能为空，请检查stock5参数", groups = {add.class, edit.class})
    private Integer stock5;

    /**
     * 牧场编码
     */
    @NotBlank(message = "牧场编码不能为空，请检查farmCode参数", groups = {add.class, edit.class})
    private String farmCode;

}
