/*
Copyright [2020] [https://www.xiaonuo.vip]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：

1.请不要删除和修改根目录下的LICENSE文件。
2.请不要删除和修改Snowy源码头部的版权声明。
3.请保留源码和相关描述文件的项目出处，作者声明等。
4.分发源码时候，请注明软件出处 https://gitee.com/xiaonuobase/snowy
5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/xiaonuobase/snowy
6.若您的项目无法满足以上几点，可申请商业授权，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.huimv.modular.heartbeatrecord.controller;

import com.huimv.core.annotion.BusinessLog;
import com.huimv.core.annotion.Permission;
import com.huimv.core.enums.LogAnnotionOpTypeEnum;
import com.huimv.core.pojo.response.ResponseData;
import com.huimv.core.pojo.response.SuccessResponseData;
import com.huimv.modular.heartbeatrecord.param.HeartBeatRecordParam;
import com.huimv.modular.heartbeatrecord.service.HeartBeatRecordService;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import javax.annotation.Resource;
import java.util.List;

/**
 * 基站心跳控制器
 *
 * @author haohao
 * @date 2021-08-20 11:00:36
 */
@RestController
public class HeartBeatRecordController {

    @Resource
    private HeartBeatRecordService heartBeatRecordService;

    /**
     * 查询基站心跳
     *
     * @author haohao
     * @date 2021-08-20 11:00:36
     */
    @Permission
    @GetMapping("/heartBeatRecord/page")
    @BusinessLog(title = "基站心跳_查询", opType = LogAnnotionOpTypeEnum.QUERY)
    public ResponseData page(HeartBeatRecordParam heartBeatRecordParam) {
        return new SuccessResponseData(heartBeatRecordService.page(heartBeatRecordParam));
    }

    /**
     * 添加基站心跳
     *
     * @author haohao
     * @date 2021-08-20 11:00:36
     */
    @Permission
    @PostMapping("/heartBeatRecord/add")
    @BusinessLog(title = "基站心跳_增加", opType = LogAnnotionOpTypeEnum.ADD)
    public ResponseData add(@RequestBody @Validated(HeartBeatRecordParam.add.class) HeartBeatRecordParam heartBeatRecordParam) {
            heartBeatRecordService.add(heartBeatRecordParam);
        return new SuccessResponseData();
    }

    /**
     * 删除基站心跳，可批量删除
     *
     * @author haohao
     * @date 2021-08-20 11:00:36
     */
    @Permission
    @PostMapping("/heartBeatRecord/delete")
    @BusinessLog(title = "基站心跳_删除", opType = LogAnnotionOpTypeEnum.DELETE)
    public ResponseData delete(@RequestBody @Validated(HeartBeatRecordParam.delete.class) List<HeartBeatRecordParam> heartBeatRecordParamList) {
            heartBeatRecordService.delete(heartBeatRecordParamList);
        return new SuccessResponseData();
    }

    /**
     * 编辑基站心跳
     *
     * @author haohao
     * @date 2021-08-20 11:00:36
     */
    @Permission
    @PostMapping("/heartBeatRecord/edit")
    @BusinessLog(title = "基站心跳_编辑", opType = LogAnnotionOpTypeEnum.EDIT)
    public ResponseData edit(@RequestBody @Validated(HeartBeatRecordParam.edit.class) HeartBeatRecordParam heartBeatRecordParam) {
            heartBeatRecordService.edit(heartBeatRecordParam);
        return new SuccessResponseData();
    }

    /**
     * 查看基站心跳
     *
     * @author haohao
     * @date 2021-08-20 11:00:36
     */
    @Permission
    @GetMapping("/heartBeatRecord/detail")
    @BusinessLog(title = "基站心跳_查看", opType = LogAnnotionOpTypeEnum.DETAIL)
    public ResponseData detail(@Validated(HeartBeatRecordParam.detail.class) HeartBeatRecordParam heartBeatRecordParam) {
        return new SuccessResponseData(heartBeatRecordService.detail(heartBeatRecordParam));
    }

    /**
     * 基站心跳列表
     *
     * @author haohao
     * @date 2021-08-20 11:00:36
     */
    @Permission
    @GetMapping("/heartBeatRecord/list")
    @BusinessLog(title = "基站心跳_列表", opType = LogAnnotionOpTypeEnum.QUERY)
    public ResponseData list(HeartBeatRecordParam heartBeatRecordParam) {
        return new SuccessResponseData(heartBeatRecordService.list(heartBeatRecordParam));
    }

    /**
     * 导出系统用户
     *
     * @author haohao
     * @date 2021-08-20 11:00:36
     */
    @Permission
    @GetMapping("/heartBeatRecord/export")
    @BusinessLog(title = "基站心跳_导出", opType = LogAnnotionOpTypeEnum.EXPORT)
    public void export(HeartBeatRecordParam heartBeatRecordParam) {
        heartBeatRecordService.export(heartBeatRecordParam);
    }

}
