/*
Copyright [2020] [https://www.xiaonuo.vip]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：

1.请不要删除和修改根目录下的LICENSE文件。
2.请不要删除和修改Snowy源码头部的版权声明。
3.请保留源码和相关描述文件的项目出处，作者声明等。
4.分发源码时候，请注明软件出处 https://gitee.com/xiaonuobase/snowy
5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/xiaonuobase/snowy
6.若您的项目无法满足以上几点，可申请商业授权，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.huimv.modular.heartbeatrecord.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.core.consts.CommonConstant;
import com.huimv.core.enums.CommonStatusEnum;
import com.huimv.core.exception.ServiceException;
import com.huimv.core.factory.PageFactory;
import com.huimv.core.pojo.page.PageResult;
import com.huimv.core.util.PoiUtil;
import com.huimv.modular.heartbeatrecord.entity.HeartBeatRecord;
import com.huimv.modular.heartbeatrecord.enums.HeartBeatRecordExceptionEnum;
import com.huimv.modular.heartbeatrecord.mapper.HeartBeatRecordMapper;
import com.huimv.modular.heartbeatrecord.param.HeartBeatRecordParam;
import com.huimv.modular.heartbeatrecord.service.HeartBeatRecordService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import javax.annotation.Resource;
import java.util.List;

/**
 * 基站心跳service接口实现类
 *
 * @author haohao
 * @date 2021-08-20 11:00:36
 */
@Service
public class HeartBeatRecordServiceImpl extends ServiceImpl<HeartBeatRecordMapper, HeartBeatRecord> implements HeartBeatRecordService {

    @Override
    public PageResult<HeartBeatRecord> page(HeartBeatRecordParam heartBeatRecordParam) {
        QueryWrapper<HeartBeatRecord> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isNotNull(heartBeatRecordParam)) {

            // 根据 查询
            if (ObjectUtil.isNotEmpty(heartBeatRecordParam.getHead())) {
                queryWrapper.lambda().eq(HeartBeatRecord::getHead, heartBeatRecordParam.getHead());
            }
            // 根据 查询
            if (ObjectUtil.isNotEmpty(heartBeatRecordParam.getDeviceCode())) {
                queryWrapper.lambda().eq(HeartBeatRecord::getDeviceCode, heartBeatRecordParam.getDeviceCode());
            }
            // 根据 查询
            if (ObjectUtil.isNotEmpty(heartBeatRecordParam.getCmd())) {
                queryWrapper.lambda().eq(HeartBeatRecord::getCmd, heartBeatRecordParam.getCmd());
            }
            // 根据 查询
            if (ObjectUtil.isNotEmpty(heartBeatRecordParam.getCheckNo())) {
                queryWrapper.lambda().eq(HeartBeatRecord::getCheckNo, heartBeatRecordParam.getCheckNo());
            }
            // 根据 查询
            if (ObjectUtil.isNotEmpty(heartBeatRecordParam.getTail())) {
                queryWrapper.lambda().eq(HeartBeatRecord::getTail, heartBeatRecordParam.getTail());
            }
            // 根据地县编码 查询
            if (ObjectUtil.isNotEmpty(heartBeatRecordParam.getCountyCode())) {
                queryWrapper.lambda().eq(HeartBeatRecord::getCountyCode, heartBeatRecordParam.getCountyCode());
            }
            // 根据牧场编码 查询
            if (ObjectUtil.isNotEmpty(heartBeatRecordParam.getFarmCode())) {
                queryWrapper.lambda().eq(HeartBeatRecord::getFarmCode, heartBeatRecordParam.getFarmCode());
            }
            // 根据猪舍id 查询
            if (ObjectUtil.isNotEmpty(heartBeatRecordParam.getPigpenId())) {
                queryWrapper.lambda().eq(HeartBeatRecord::getPigpenId, heartBeatRecordParam.getPigpenId());
            }
            // 根据单元id 查询
            if (ObjectUtil.isNotEmpty(heartBeatRecordParam.getUnitId())) {
                queryWrapper.lambda().eq(HeartBeatRecord::getUnitId, heartBeatRecordParam.getUnitId());
            }
        }
        return new PageResult<>(this.page(PageFactory.defaultPage(), queryWrapper));
    }

    @Override
    public List<HeartBeatRecord> list(HeartBeatRecordParam heartBeatRecordParam) {
        return this.list();
    }

    @Override
    public void add(HeartBeatRecordParam heartBeatRecordParam) {
        HeartBeatRecord heartBeatRecord = new HeartBeatRecord();
        BeanUtil.copyProperties(heartBeatRecordParam, heartBeatRecord);
        this.save(heartBeatRecord);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<HeartBeatRecordParam> heartBeatRecordParamList) {
        heartBeatRecordParamList.forEach(heartBeatRecordParam -> {
            this.removeById(heartBeatRecordParam.getId());
        });
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(HeartBeatRecordParam heartBeatRecordParam) {
        HeartBeatRecord heartBeatRecord = this.queryHeartBeatRecord(heartBeatRecordParam);
        BeanUtil.copyProperties(heartBeatRecordParam, heartBeatRecord);
        this.updateById(heartBeatRecord);
    }

    @Override
    public HeartBeatRecord detail(HeartBeatRecordParam heartBeatRecordParam) {
        return this.queryHeartBeatRecord(heartBeatRecordParam);
    }

    /**
     * 获取基站心跳
     *
     * @author haohao
     * @date 2021-08-20 11:00:36
     */
    private HeartBeatRecord queryHeartBeatRecord(HeartBeatRecordParam heartBeatRecordParam) {
        HeartBeatRecord heartBeatRecord = this.getById(heartBeatRecordParam.getId());
        if (ObjectUtil.isNull(heartBeatRecord)) {
            throw new ServiceException(HeartBeatRecordExceptionEnum.NOT_EXIST);
        }
        return heartBeatRecord;
    }

    @Override
    public void export(HeartBeatRecordParam heartBeatRecordParam) {
        List<HeartBeatRecord> list = this.list(heartBeatRecordParam);
        PoiUtil.exportExcelWithStream("SnowyHeartBeatRecord.xls", HeartBeatRecord.class, list);
    }

}
