/*
Copyright [2020] [https://www.xiaonuo.vip]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：

1.请不要删除和修改根目录下的LICENSE文件。
2.请不要删除和修改Snowy源码头部的版权声明。
3.请保留源码和相关描述文件的项目出处，作者声明等。
4.分发源码时候，请注明软件出处 https://gitee.com/xiaonuobase/snowy
5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/xiaonuobase/snowy
6.若您的项目无法满足以上几点，可申请商业授权，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.huimv.modular.movepigpen.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.core.consts.CommonConstant;
import com.huimv.core.enums.CommonStatusEnum;
import com.huimv.core.exception.ServiceException;
import com.huimv.core.factory.PageFactory;
import com.huimv.core.pojo.page.PageResult;
import com.huimv.core.util.PoiUtil;
import com.huimv.modular.movepigpen.entity.MovePigpen;
import com.huimv.modular.movepigpen.enums.MovePigpenExceptionEnum;
import com.huimv.modular.movepigpen.mapper.MovePigpenMapper;
import com.huimv.modular.movepigpen.param.MovePigpenParam;
import com.huimv.modular.movepigpen.service.MovePigpenService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import javax.annotation.Resource;
import java.util.List;

/**
 * 转舍service接口实现类
 *
 * @author ydd
 * @date 2021-08-20 17:03:16
 */
@Service
public class MovePigpenServiceImpl extends ServiceImpl<MovePigpenMapper, MovePigpen> implements MovePigpenService {

    @Override
    public PageResult<MovePigpen> page(MovePigpenParam movePigpenParam) {
        QueryWrapper<MovePigpen> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isNotNull(movePigpenParam)) {

            // 根据组织id 查询
            if (ObjectUtil.isNotEmpty(movePigpenParam.getOrgId())) {
                queryWrapper.lambda().eq(MovePigpen::getOrgId, movePigpenParam.getOrgId());
            }
            // 根据耳标号 查询
            if (ObjectUtil.isNotEmpty(movePigpenParam.getEartagNo())) {
                queryWrapper.lambda().eq(MovePigpen::getEartagNo, movePigpenParam.getEartagNo());
            }
            // 根据转舍日期 查询
            if (ObjectUtil.isNotEmpty(movePigpenParam.getMoveDate())) {
                queryWrapper.lambda().eq(MovePigpen::getMoveDate, movePigpenParam.getMoveDate());
            }
            // 根据当前阶段 查询
            if (ObjectUtil.isNotEmpty(movePigpenParam.getStage())) {
                queryWrapper.lambda().eq(MovePigpen::getStage, movePigpenParam.getStage());
            }
            // 根据设备编码 查询
            if (ObjectUtil.isNotEmpty(movePigpenParam.getDeviceCode())) {
                queryWrapper.lambda().eq(MovePigpen::getDeviceCode, movePigpenParam.getDeviceCode());
            }
        }
        return new PageResult<>(this.page(PageFactory.defaultPage(), queryWrapper));
    }

    @Override
    public List<MovePigpen> list(MovePigpenParam movePigpenParam) {
        return this.list();
    }

    @Override
    public void add(MovePigpenParam movePigpenParam) {
        MovePigpen movePigpen = new MovePigpen();
        BeanUtil.copyProperties(movePigpenParam, movePigpen);
        this.save(movePigpen);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<MovePigpenParam> movePigpenParamList) {
        movePigpenParamList.forEach(movePigpenParam -> {
            this.removeById(movePigpenParam.getId());
        });
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(MovePigpenParam movePigpenParam) {
        MovePigpen movePigpen = this.queryMovePigpen(movePigpenParam);
        BeanUtil.copyProperties(movePigpenParam, movePigpen);
        this.updateById(movePigpen);
    }

    @Override
    public MovePigpen detail(MovePigpenParam movePigpenParam) {
        return this.queryMovePigpen(movePigpenParam);
    }

    /**
     * 获取转舍
     *
     * @author ydd
     * @date 2021-08-20 17:03:16
     */
    private MovePigpen queryMovePigpen(MovePigpenParam movePigpenParam) {
        MovePigpen movePigpen = this.getById(movePigpenParam.getId());
        if (ObjectUtil.isNull(movePigpen)) {
            throw new ServiceException(MovePigpenExceptionEnum.NOT_EXIST);
        }
        return movePigpen;
    }

    @Override
    public void export(MovePigpenParam movePigpenParam) {
        List<MovePigpen> list = this.list(movePigpenParam);
        PoiUtil.exportExcelWithStream("SnowyMovePigpen.xls", MovePigpen.class, list);
    }

}
